@@ -24,6 +24,7 @@ from typing import (
 
 import typic.constraints as c
 from typic.checks import issubclass, ishashable, isfrozendataclass
+from typic.compat import lru_cache
 from typic.serde.binder import BoundArguments
 from typic.serde.common import (
     Annotation,
@@ -190,7 +191,7 @@ def _bind_proto(cls, proto: SerdeProtocol):
         setattr(cls, n, attr)
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def _resolve_class(
     cls: Type[ObjectT],
     *,
@@ -199,6 +200,7 @@ def _resolve_class(
     serde: SerdeFlags = None,
 ) -> Type[WrappedObjectT]:
     # Build the namespace for the new class
+    strict = cast(bool, strict)
     protos = protocols(cls, strict=strict)
     if hasattr(cls, SERDE_FLAGS_ATTR):
         pserde: SerdeFlags = getattr(cls, SERDE_FLAGS_ATTR)
@@ -225,7 +227,9 @@ def _resolve_class(
             @functools.wraps(setter)
             def __setattr_typed__(self, name, item, *, __trans=trans, __setter=setter):
                 __setter(
-                    self, name, __trans[name](item) if name in protos else item,
+                    self,
+                    name,
+                    __trans[name](item) if name in protos else item,
                 )
 
             return __setattr_typed__
@@ -431,11 +435,7 @@ def _handle_constraint_values(constraints, values, args):
     if vcons:
         constraints["values"] = vcons
         if not isinstance(values, tuple) or len(values) == 1:
-            args = (
-                values  # type: ignore
-                if isinstance(values, tuple)
-                else (values,)
-            )
+            args = values if isinstance(values, tuple) else (values,)  # type: ignore
     return args
 
 
@@ -704,7 +704,7 @@ SchemaPrimitiveT = Dict[str, PrimitiveT]
 SchemaReturnT = Union[SchemaPrimitiveT, ObjectSchemaField]
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def schema(obj: Type[ObjectT], *, primitive: bool = False) -> SchemaReturnT:
     """Get a JSON schema for object for the given object.
 
