@@ -89,7 +89,7 @@ def unique(seq: Sequence, *, ret_type: Type[Union[list, tuple]] = list) -> Seque
         return unique_slow(seq, ret_type=ret_type)
 
 
-@util.apply_slots
+@util.slotted
 @dataclasses.dataclass(frozen=True, repr=False)
 class ArrayConstraints(BaseConstraints):
     """Specific constraints pertaining to a sized, array-like type.
@@ -152,7 +152,7 @@ class ArrayConstraints(BaseConstraints):
                 f"{o.__name__}("
                 f"({itval}(x, field={field}) for i, x in enumerate({self.VALUE}))"
                 f")",
-                **ctx,
+                **ctx,  # type: ignore
             )
         return asserts, context
 
@@ -162,14 +162,13 @@ class ArrayConstraints(BaseConstraints):
             minItems=self.min_items,
             maxItems=self.max_items,
             uniqueItems=self.unique,
-            items=self.values.for_schema(with_type=True) if self.values else None,
         )
         if with_type:
             schema["type"] = "array"
         return {x: y for x, y in schema.items() if y is not None}
 
 
-@util.apply_slots
+@util.slotted
 @dataclasses.dataclass(frozen=True, repr=False)
 class ListContraints(ArrayConstraints):
     """Specific constraints pertaining to a :py:class:`list`."""
@@ -177,7 +176,7 @@ class ListContraints(ArrayConstraints):
     type: ClassVar[Type[list]] = list
 
 
-@util.apply_slots
+@util.slotted
 @dataclasses.dataclass(frozen=True, repr=False)
 class TupleContraints(ArrayConstraints):
     """Specific constraints pertaining to a :py:class:`tuple`."""
@@ -185,7 +184,7 @@ class TupleContraints(ArrayConstraints):
     type: ClassVar[Type[tuple]] = tuple
 
 
-@util.apply_slots
+@util.slotted
 @dataclasses.dataclass(frozen=True, repr=False)
 class SetContraints(ArrayConstraints):
     """Specific constraints pertaining to a :py:class:`set`."""
@@ -194,7 +193,7 @@ class SetContraints(ArrayConstraints):
     unique: bool = True
 
 
-@util.apply_slots
+@util.slotted
 @dataclasses.dataclass(frozen=True, repr=False)
 class FrozenSetConstraints(ArrayConstraints):
     """Specific constraints pertaining to a :py:class:`frozenset`."""
