@@ -30,7 +30,7 @@ from typic.common import (
     Case,
     ReadOnly,
 )
-from typic.compat import ForwardRef
+from typic.compat import ForwardRef, lru_cache
 from typic.strict import StrictModeT
 from .binder import Binder
 from .common import (
@@ -47,7 +47,6 @@ from .common import (
 from .des import DesFactory
 from .ser import SerFactory
 from .translator import TranslatorFactory
-from ..util import guard_recursion, RecursionDetected
 
 _T = TypeVar("_T")
 
@@ -69,6 +68,7 @@ class Resolver:
         self.translator = TranslatorFactory(self)
         self.bind = self.binder.bind
         self.__cache = {}
+        self.__stack = set()
         for typ in checks.STDLIB_TYPES:
             self.resolve(typ)
             self.resolve(Optional[typ])
@@ -180,7 +180,7 @@ class Resolver:
     def delayed(self, t: Type) -> bool:
         return getattr(t, "__delayed__", False)
 
-    @functools.lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)
     def _get_serializer_proto(self, t: Type) -> SerdeProtocol:
         tname = util.get_name(t)
         if hasattr(t, SERDE_ATTR):
@@ -314,7 +314,7 @@ class Resolver:
         proto: SerdeProtocol = self._get_serializer_proto(t)
         return proto.tojson(obj, indent=indent, ensure_ascii=ensure_ascii, **kwargs)
 
-    @functools.lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)
     def _get_configuration(self, origin: Type, flags: "SerdeFlags") -> "SerdeConfig":
         if hasattr(origin, SERDE_FLAGS_ATTR):
             flags = getattr(origin, SERDE_FLAGS_ATTR)
@@ -324,17 +324,15 @@ class Resolver:
         fields: Dict[
             str, Union[Annotation, DelayedAnnotation, ForwardDelayedAnnotation]
         ] = {}
-        for name, anno in util.cached_type_hints(origin).items():
-            kwargs = dict(
+        hints = util.cached_type_hints(origin)
+        for name, t in hints.items():
+            fields[name] = self.annotation(
+                t,
                 flags=dataclasses.replace(flags, fields={}),
                 default=getattr(origin, name, EMPTY),
                 namespace=origin,
             )
-            with guard_recursion():  # pragma: nocover
-                try:
-                    fields[name] = self.annotation(anno, **kwargs)
-                except RecursionDetected:
-                    fields[name] = self.annotation(anno, recursive=True, **kwargs)
+
         # Filter out any annotations which aren't part of the object's signature.
         if flags.signature_only:
             fields = {x: fields[x] for x in fields.keys() & params.keys()}
@@ -361,6 +359,7 @@ class Resolver:
             type_name_omissions = {util.get_name(o) for o in type_omissions}
             value_omissions = (*(o for o in omit if o not in type_omissions),)
             fields_out_final = {}
+            anno: Union[Annotation, DelayedAnnotation, ForwardDelayedAnnotation]
             for name, out in fields_out.items():
                 anno = fields[name]
                 default = anno.parameter.default if anno.parameter else EMPTY
@@ -400,7 +399,6 @@ class Resolver:
         flags: "SerdeFlags" = None,
         default: Any = EMPTY,
         namespace: Type = None,
-        recursive: bool = False,
     ) -> Union[Annotation, DelayedAnnotation, ForwardDelayedAnnotation]:
         """Get a :py:class:`Annotation` for this type.
 
@@ -415,7 +413,7 @@ class Resolver:
                 name or "_",
                 inspect.Parameter.POSITIONAL_OR_KEYWORD,
                 annotation=annotation,
-                default=default,
+                default=default if checks.ishashable(default) else ...,
             )
         # Check for the super-type
         non_super = util.resolve_supertype(annotation)
@@ -467,7 +465,9 @@ class Resolver:
                 module=module,
                 localns=localns,
             )
-        elif use is namespace or recursive:
+        elif use is namespace or use in self.__stack:
+            if use in self.__stack:
+                self.__stack.remove(use)
             return DelayedAnnotation(
                 type=use,
                 resolver=self,
@@ -478,6 +478,7 @@ class Resolver:
                 flags=flags,
                 default=default,
             )
+        self.__stack.add(use)
         serde = (
             self._get_configuration(util.origin(use), flags)
             if is_static
@@ -497,7 +498,7 @@ class Resolver:
         anno.translator = functools.partial(self.translator.factory, anno)  # type: ignore
         return anno
 
-    @functools.lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)
     def _resolve_from_annotation(
         self,
         anno: Union[Annotation, DelayedAnnotation, ForwardDelayedAnnotation],
@@ -535,7 +536,7 @@ class Resolver:
         self.__cache[anno] = proto
         return proto
 
-    @functools.lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)
     def resolve(
         self,
         annotation: Type[ObjectT],
@@ -583,6 +584,7 @@ class Resolver:
         --------
         :py:class:`SerdeProtocol`
         """
+        # self.__stack.clear()
         # Extract the meta-data.
         anno = self.annotation(
             annotation=annotation,
@@ -594,9 +596,10 @@ class Resolver:
             namespace=namespace,
         )
         resolved = self._resolve_from_annotation(anno, _des, _ser, namespace)
+        self.__stack.clear()
         return resolved
 
-    @functools.lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)
     def protocols(self, obj, *, strict: bool = False) -> SerdeProtocolsT:
         """Get a mapping of param/attr name -> :py:class:`SerdeProtocol`
 
@@ -647,9 +650,10 @@ class Resolver:
             )
             if repr(param.default) == "<factory>":
                 param = param.replace(default=EMPTY)
-            if annotation is ClassVar:
+            if checks.isclassvartype(annotation):
                 val = getattr(obj, name)
-                annotation = annotation[type(val)]
+                if annotation is ClassVar:
+                    annotation = annotation[type(val)]
                 default = val
                 param = param.replace(default=default)
             if (
@@ -661,8 +665,15 @@ class Resolver:
                     annotation = ReadOnly[annotation]  # type: ignore
                 param = param.replace(default=field.default)
 
+            if not checks.ishashable(param.default):
+                param = param.replace(default=...)
+
             resolved = self.resolve(
-                annotation, parameter=param, name=name, is_strict=strict, namespace=obj,
+                annotation,
+                parameter=param,
+                name=name,
+                is_strict=strict,
+                namespace=obj,
             )
             ann[name] = resolved
         try:
