@@ -101,7 +101,12 @@ def make_class_serdict(annotation: "Annotation", fields: Mapping[str, Serializer
     else:
 
         def missing(  # type: ignore
-            self, item, *, __fields=fields, __getters=getters, __repr=util.joinedrepr,
+            self,
+            item,
+            *,
+            __fields=fields,
+            __getters=getters,
+            __repr=util.joinedrepr,
         ):
             self[item] = ret = __fields[item](
                 __getters[item](self.instance),
@@ -147,7 +152,11 @@ class ClassFieldSerDict(dict):
     __slots__ = ("instance", "lazy", "_name")
 
     def __init__(
-        self, instance: Any, lazy: bool = False, *, __tfname__: util.ReprT = None,
+        self,
+        instance: Any,
+        lazy: bool = False,
+        *,
+        __tfname__: util.ReprT = None,
     ):
         self._name = __tfname__
         self.instance = instance
@@ -185,7 +194,9 @@ def make_kv_serdict(annotation: "Annotation", kser: SerializerT, vser: Serialize
                 if value in __omit:
                     return Omit
                 newv = __vser(  # type: ignore
-                    value, lazy=self.lazy, name=__repr(self._name, key),
+                    value,
+                    lazy=self.lazy,
+                    name=__repr(self._name, key),
                 )
                 self[key] = newv
                 return newv
@@ -298,7 +309,9 @@ class SerList(list):
     def append(self, object: _T) -> None:  # pragma: nocover
         super().append(
             self.serializer(  # type: ignore
-                object, lazy=self.lazy, name=self.repr(self._name, len(self)),
+                object,
+                lazy=self.lazy,
+                name=self.repr(self._name, len(self)),
             )
         )
 
@@ -385,7 +398,7 @@ class SerFactory:
         resolved_name = util.get_name(annotation.resolved)
         func.l(f"{self._FNAME} = name or {resolved_name!r}")
         line = "if not tcheck(o.__class__, t):"
-        check: Callable[[Any], bool] = util.cached_issubclass
+        check: Callable[..., bool] = util.cached_issubclass
         if checks.isbuiltinsubtype(annotation.generic):
             line = "if not tcheck(o, t):"
             check = isinstance  # type: ignore
@@ -406,7 +419,9 @@ class SerFactory:
             )
 
     def _build_list_serializer(
-        self, func: gen.Block, annotation: "Annotation",
+        self,
+        func: gen.Block,
+        annotation: "Annotation",
     ):
         # Check for value types
         line = "[*o]"
@@ -455,7 +470,10 @@ class SerFactory:
         return main.compile(name=name, ns=ns)
 
     def _finalize_mapping_serializer(
-        self, func: gen.Block, serdict: Type, annotation: "Annotation",
+        self,
+        func: gen.Block,
+        serdict: Type,
+        annotation: "Annotation",
     ):
         serdict_name = serdict.__name__
         self._check_add_null_check(func, annotation)
@@ -494,7 +512,9 @@ class SerFactory:
         self._finalize_mapping_serializer(func, serdict, annotation)
 
     def _build_class_serializer(
-        self, func: gen.Block, annotation: "Annotation",
+        self,
+        func: gen.Block,
+        annotation: "Annotation",
     ):
         # Get the field serializers
         fields_ser = {x: self.factory(y) for x, y in annotation.serde.fields.items()}
@@ -503,7 +523,7 @@ class SerFactory:
 
         self._finalize_mapping_serializer(func, serdict, annotation)
 
-    def _compile_enum_serializer(self, annotation: "Annotation",) -> SerializerT:
+    def _compile_enum_serializer(self, annotation: "Annotation") -> SerializerT:
         origin: Type[enum.Enum] = cast(Type[enum.Enum], annotation.resolved_origin)
         ts = {type(x.value) for x in origin}
         # If we can predict a single type the return the serializer for that
@@ -522,7 +542,9 @@ class SerFactory:
         return self.resolver.primitive
 
     def _compile_defined_serializer(
-        self, annotation: "Annotation", ser: SerializerT,
+        self,
+        annotation: "Annotation",
+        ser: SerializerT,
     ) -> SerializerT:
         func_name = self._get_name(annotation)
         ser_name = "ser"
@@ -641,7 +663,7 @@ class SerFactory:
 
 
 class DelayedSerializer:
-    __slots__ = "anno", "factory", "_serializer"
+    __slots__ = "anno", "factory", "_serializer", "__name__"
 
     def __init__(
         self,
@@ -651,6 +673,7 @@ class DelayedSerializer:
         self.anno = anno
         self.factory = factory
         self._serializer: Optional[SerializerT] = None
+        self.__name__ = anno.name
 
     def __call__(self, *args, **kwargs):
         if self._serializer is None:
