@@ -20,7 +20,7 @@ from typing import (  # type: ignore  # ironic...
     Type,
     TypeVar,
     Callable,
-    get_type_hints,
+    get_type_hints as _get_type_hints,
     Union,
     MutableMapping,
     MutableSequence,
@@ -33,8 +33,8 @@ from typing import (  # type: ignore  # ironic...
 )
 
 import typic.checks as checks
+from typic.compat import ForwardRef, lru_cache
 from typic.ext import json
-from typic.compat import ForwardRef
 
 __all__ = (
     "cached_issubclass",
@@ -45,12 +45,18 @@ __all__ = (
     "cachedmethod",
     "fastcachedmethod",
     "filtered_repr",
+    "guard_recursion",
     "get_args",
     "get_name",
+    "get_defname",
+    "get_qualname",
+    "get_type_hints",
+    "get_unique_name",
     "origin",
     "resolve_supertype",
     "safe_eval",
     "safe_get_params",
+    "signature",
     "simple_attributes",
     "slotted",
     "typed_dict_signature",
@@ -81,7 +87,7 @@ GENERIC_TYPE_MAP = {
 }
 
 
-@functools.lru_cache(maxsize=2000, typed=True)
+@lru_cache(maxsize=2000, typed=True)
 def safe_eval(string: str) -> Tuple[bool, Any]:
     """Try a few methods to evaluate a string and get the correct Python data-type.
 
@@ -132,7 +138,7 @@ def filtered_str(self) -> str:
     return f"({', '.join(fields)})"
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def origin(annotation: Any) -> Any:
     """Get the highest-order 'origin'-type for subclasses of typing._SpecialForm.
 
@@ -173,7 +179,7 @@ def origin(annotation: Any) -> Any:
     return actual
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def get_args(annotation: Any) -> Tuple[Any, ...]:
     """Get the args supplied to an annotation, excluding :py:class:`typing.TypeVar`.
 
@@ -194,8 +200,8 @@ def get_args(annotation: Any) -> Tuple[Any, ...]:
     )
 
 
-@functools.lru_cache(maxsize=None)
-def get_name(obj: Union[Type, ForwardRef]) -> str:
+@lru_cache(maxsize=None)
+def get_name(obj: Union[Type, ForwardRef, Callable]) -> str:
     """Safely retrieve the name of either a standard object or a type annotation.
 
     Examples
@@ -219,7 +225,7 @@ def get_name(obj: Union[Type, ForwardRef]) -> str:
     return obj.__name__
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def get_qualname(obj: Type) -> str:
     if hasattr(obj, "_name") and not hasattr(obj, "__name__"):
         return repr(obj)
@@ -233,17 +239,17 @@ def get_qualname(obj: Type) -> str:
     return qualname
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def get_unique_name(obj: Type) -> str:
     return f"{get_name(obj)}_{id(obj)}".replace("-", "_")
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def get_defname(pre: str, obj: Hashable) -> str:
     return f"{pre}_{hash(obj)}".replace("-", "_")
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def resolve_supertype(annotation: Type[Any]) -> Any:
     """Get the highest-order supertype for a NewType.
 
@@ -397,27 +403,33 @@ def fastcachedmethod(func):
     return _fast_cached_method_wrapper
 
 
-@functools.lru_cache(maxsize=None)
-def cached_signature(obj: Callable) -> inspect.Signature:
-    """A cached result of :py:func:`inspect.signature`.
+def signature(obj: Union[Callable, Type]) -> inspect.Signature:
+    """Get the signature of a type or callable.
 
-    Building the function signature is notoriously slow, but we can be safe that the
-    signature won't change at runtime, so we cache the result.
-
-    We also provide a little magic so that we can introspect :py:class:`TypedDict`
+    Also supports TypedDict subclasses
     """
     return (
-        typed_dict_signature(obj) if checks.istypeddict(obj) else inspect.signature(obj)
+        typed_dict_signature(obj)
+        if checks.istypeddict(obj)  # type: ignore
+        else inspect.signature(obj)
     )
 
 
+cached_signature = lru_cache(maxsize=None)(signature)
+
+
 def _safe_get_type_hints(annotation: Union[Type, Callable]) -> Dict[str, Type[Any]]:
-    raw_annotations = getattr(annotation, "__annotations__", None) or {}
-    module_name = getattr(annotation, "__module__", None)
-    if module_name:
-        base_globals: Optional[Dict[str, Any]] = sys.modules[module_name].__dict__
+    raw_annotations: Dict[str, Any] = {}
+    base_globals: Dict[str, Any] = {}
+    if isinstance(annotation, type):
+        for base in reversed(annotation.__mro__):
+            base_globals.update(sys.modules[base.__module__].__dict__)
+            raw_annotations.update(getattr(base, "__annotations__", None) or {})
     else:
-        base_globals = None
+        raw_annotations = getattr(annotation, "__annotations__", None) or {}
+        module_name = getattr(annotation, "__module__", None)
+        if module_name:
+            base_globals = sys.modules[module_name].__dict__
     annotations = {}
     for name, value in raw_annotations.items():
         if isinstance(value, str):
@@ -426,27 +438,25 @@ def _safe_get_type_hints(annotation: Union[Type, Callable]) -> Dict[str, Type[An
             else:
                 value = ForwardRef(value)
         try:
-            value = _eval_type(value, base_globals, None)
+            value = _eval_type(value, base_globals or None, None)
         except NameError:
-            # this is ok, it can be fixed with update_forward_refs
+            # this is ok, we deal with it later.
             pass
         annotations[name] = value
     return annotations
 
 
-@functools.lru_cache(maxsize=None)
-def cached_type_hints(obj: Union[Type, Callable]) -> dict:
-    """A cached result of :py:func:`typing.get_type_hints`.
-
-    We don't want to go through the process of resolving type-hints every time.
-    """
+def get_type_hints(obj: Union[Type, Callable]) -> Dict[str, Type[Any]]:
     try:
-        return get_type_hints(obj)
+        return _get_type_hints(obj)
     except NameError:
         return _safe_get_type_hints(obj)
 
 
-@functools.lru_cache(maxsize=None)
+cached_type_hints = lru_cache(maxsize=None)(get_type_hints)
+
+
+@lru_cache(maxsize=None)
 def cached_issubclass(st: Type, t: Union[Type, Tuple[Type, ...]]) -> bool:
     """A cached result of :py:func:`issubclass`."""
     return issubclass(st, t)
@@ -463,7 +473,7 @@ def simple_attributes(t: Type) -> Tuple[str, ...]:
     )
 
 
-cached_simple_attributes = functools.lru_cache(maxsize=None)(simple_attributes)
+cached_simple_attributes = lru_cache(maxsize=None)(simple_attributes)
 """A cached result of :py:func:`simple_attributes`."""
 
 
@@ -487,7 +497,7 @@ def typed_dict_signature(obj: Callable) -> inspect.Signature:
     )
 
 
-@functools.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def safe_get_params(obj: Type) -> Mapping[str, inspect.Parameter]:
     params: Mapping[str, inspect.Parameter]
     try:
@@ -549,6 +559,7 @@ class RecursionDetector(bdb.Bdb):  # pragma: nocover
     def user_call(self, frame, argument_list):
         code = frame.f_code
         if code in self.stack:
+            self.stack.clear()
             raise RecursionDetected(f"Caught recursion in: {frame}")
         self.stack.add(code)
 
@@ -572,7 +583,10 @@ def guard_recursion():  # pragma: nocover
 
 
 def slotted(
-    _cls: Type = None, *, dict: bool = True, weakref: bool = False,
+    _cls: Type = None,
+    *,
+    dict: bool = True,
+    weakref: bool = False,
 ):
     """Decorator to create a "slotted" version of the provided class.
 
@@ -627,7 +641,7 @@ def slotted(
 
 
 class joinedrepr(str):
-    __slots__ = ("fields",)
+    __slots__ = ("fields", "__dict__")
     fields: Iterable[Any]
 
     def __new__(cls, *fields):
@@ -650,6 +664,7 @@ class collectionrepr(str):
     __slots__ = (
         "root_name",
         "keys",
+        "__dict__",
     )
     root_name: str
     keys: Iterable[Any]
